#pragma once

#include "common.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef struct RecollectClient RecollectSession;

typedef void (*TodayFrameNumberChangedCallback)(unsigned int frameNumber,
                                                void *);
typedef void (*ActiveAppChangedCallback)(const char *appDesktopEntry, void *);
typedef void (*RecordingMemoryChangedCallback)(bool recording, void *);
typedef void (*BackInTimeDetectedCallback)(void *);
typedef void (*FrameDeletedCallback)(const char *date, int frameIndex, void *);

RecollectSession *recollect_create_session();

RecollectionStatus recollect_init_session(RecollectSession *session);

void recollect_destroy_session(RecollectSession **session);

void recollect_result_free(char *result);

RecollectionStatus recollect_get_ocr_screenshot_data(RecollectSession *session,
                                                     const char *searchQuery,
                                                     char **result);

RecollectionStatus
recollect_get_visual_screenshot_data(RecollectSession *session,
                                     const char *searchQuery, char **result);

RecollectionStatus
recollect_get_screenshot_data_of_day(RecollectSession *session,
                                     const char *dayAndIndex, char **result);

RecollectionStatus recollect_get_screenshot_image_of_video_by_index(
    RecollectSession *session, const char *videoNameAndIndex, ImageData *image);

void recollect_image_free(ImageData *imageData);

RecollectionStatus recollect_get_first_and_last_day(RecollectSession *session,
                                                    char **result);

RecollectionStatus recollect_get_app_list_of_day(RecollectSession *session,
                                                 const char *day,
                                                 char **result);

RecollectionStatus recollect_delete_user_data(RecollectSession *session,
                                              const char *timeRange);

void recollect_set_today_frame_number_changed_callback(
    RecollectSession *session, TodayFrameNumberChangedCallback callback,
    void *todayFrameNumberChangedUserData);

void recollect_set_active_app_changed_callback(
    RecollectSession *session, ActiveAppChangedCallback callback,
    void *activeAppChangedUserData);

void recollect_set_back_in_time_detected_callback(
    RecollectSession *session, BackInTimeDetectedCallback callback,
    void *backInTimeDetectedUserData);

void recollect_set_frame_deleted_callback(RecollectSession *session,
                                          FrameDeletedCallback callback,
                                          void *frameDeletedUserData);

RecollectionStatus recollect_set_recording_memory(RecollectSession *session,
                                                  bool recording);

RecollectionStatus recollect_get_recording_memory(RecollectSession *session,
                                                  bool *recording);

void recollect_set_recording_changed_callback(
    RecollectSession *session, RecordingMemoryChangedCallback callback,
    void *recordingChangedUserData);

RecollectionStatus recollect_set_screenshot_interval(RecollectSession *session,
                                                     unsigned int seconds);

RecollectionStatus recollect_get_screenshot_interval(RecollectSession *session,
                                                     unsigned int *seconds);

RecollectionStatus recollect_set_maximum_storage_gb(RecollectSession *session,
                                                    unsigned int gigabytes);

RecollectionStatus recollect_get_maximum_storage_gb(RecollectSession *session,
                                                    unsigned int *gigabytes);

#ifdef __cplusplus
}
#endif
